@@ -65,6 +65,7 @@ public:
         mAboutApp = 0;
         mAboutKDE = 0;
         mBugReport = 0;
+        mDonateAction = 0;
         mHandBookAction = 0;
         mWhatsThisAction = 0;
         mReportBugAction = 0;
@@ -86,6 +87,7 @@ public:
     QDialog *mAboutApp;
     KAboutKdeDialog *mAboutKDE;
     KBugReport *mBugReport;
+    QAction *mDonateAction;
     KSwitchLanguageDialog *mSwitchApplicationLanguage;
 
 // TODO evaluate if we use static_cast<QWidget*>(parent()) instead of mParent to win that bit of memory
@@ -133,42 +135,33 @@ void KHelpMenuPrivate::createActions(KHelpMenu *q)
     }
     mActionsCreated = true;
 
-    if (KAuthorized::authorizeKAction(QStringLiteral("help_contents"))) {
+    if (KAuthorized::authorizeAction(QStringLiteral("help_contents"))) {
         mHandBookAction = KStandardAction::helpContents(q, SLOT(appHelpActivated()), q);
     }
-    if (mShowWhatsThis && KAuthorized::authorizeKAction(QStringLiteral("help_whats_this"))) {
+    if (mShowWhatsThis && KAuthorized::authorizeAction(QStringLiteral("help_whats_this"))) {
         mWhatsThisAction = KStandardAction::whatsThis(q, SLOT(contextHelpActivated()), q);
     }
 
-    if (KAuthorized::authorizeKAction(QStringLiteral("help_report_bug")) && !mAboutData.bugAddress().isEmpty()) {
+    if (KAuthorized::authorizeAction(QStringLiteral("help_report_bug")) && !mAboutData.bugAddress().isEmpty()) {
         mReportBugAction = KStandardAction::reportBug(q, SLOT(reportBug()), q);
     }
 
-    if (KAuthorized::authorizeKAction(QStringLiteral("switch_application_language"))) {
-        // Is more than one language installed?
-        const QStringList localeDirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("locale"), QStandardPaths::LocateDirectory);
-        int numFiles = 0;
-        Q_FOREACH (const QString &localeDir, localeDirs) {
-            const QStringList entries = QDir(localeDir).entryList(QDir::Dirs);
-            Q_FOREACH (const QString &d, entries) {
-                if (QFile::exists(localeDir + QLatin1Char('/') + d + QStringLiteral("/entry.desktop"))) {
-                    ++numFiles;
-                    if (numFiles > 1) {
-                        break;
-                    }
-                }
-            }
-        }
-        if (numFiles > 1) {
+    if (KAuthorized::authorizeAction(QStringLiteral("help_donate"))
+        && mAboutData.bugAddress() == QStringLiteral("submit@bugs.kde.org")) {
+        mDonateAction = KStandardAction::donate(q, &KHelpMenu::donate, q);
+    }
+
+    if (KAuthorized::authorizeAction(QStringLiteral("switch_application_language"))) {
+        if (KLocalizedString::availableApplicationTranslations().count() > 1) {
             mSwitchApplicationLanguageAction = KStandardAction::create(KStandardAction::SwitchApplicationLanguage, q, SLOT(switchApplicationLanguage()), q);
         }
     }
 
-    if (KAuthorized::authorizeKAction(QStringLiteral("help_about_app"))) {
+    if (KAuthorized::authorizeAction(QStringLiteral("help_about_app"))) {
         mAboutAppAction = KStandardAction::aboutApp(q, SLOT(aboutApplication()), q);
     }
 
-    if (KAuthorized::authorizeKAction(QStringLiteral("help_about_kde"))) {
+    if (KAuthorized::authorizeAction(QStringLiteral("help_about_kde"))) {
         mAboutKDEAction = KStandardAction::aboutKDE(q, SLOT(aboutKDE()), q);
     }
 }
@@ -203,6 +196,14 @@ QMenu *KHelpMenu::menu()
             need_separator = true;
         }
 
+        if (d->mDonateAction) {
+            if (need_separator) {
+                d->mMenu->addSeparator();
+            }
+            d->mMenu->addAction(d->mDonateAction);
+            need_separator = true;
+        }
+
         if (d->mSwitchApplicationLanguageAction) {
             if (need_separator) {
                 d->mMenu->addSeparator();
@@ -253,6 +254,10 @@ QAction *KHelpMenu::action(MenuId id) const
     case menuAboutKDE:
         return d->mAboutKDEAction;
         break;
+
+    case menuDonate:
+        return d->mDonateAction;
+        break;
     }
 
     return 0;
@@ -345,6 +350,11 @@ void KHelpMenu::switchApplicationLanguage()
     d->mSwitchApplicationLanguage->show();
 }
 
+void KHelpMenu::donate()
+{
+    QDesktopServices::openUrl(QUrl(QStringLiteral("https://www.kde.org/donate?app=%1").arg(d->mAboutData.componentName())));
+}
+
 void KHelpMenu::dialogFinished()
 {
     QTimer::singleShot(0, this, SLOT(timerExpired()));
